@@ -50,8 +50,8 @@ func Error(c iris.Context, code int, err error) {
 	c.StopWithJSON(query.StatusCode(code), resp)
 }
 
-func ErrorInvalidParams(c iris.Context, err error) {
-	Error(c, query.ErrInvalidParams, err)
+func ErrorInvalidParameters(c iris.Context, err error) {
+	Error(c, query.ErrInvalidParameters, err)
 }
 
 func ErrorUnexpected(c iris.Context, err error) {
